%define name boost
%define version 1.29.0
%define release 4mdk
%define lib_name_orig libboost
%define lib_major 1.29
%define lib_name %{lib_name_orig}%{lib_major}

# For SRPM only
Name: %{name}
Summary: Portable C++ libraries.
Version: %{version}
Release: %{release}
License: BSD
Group: Development/C++
Source: %{name}_1_29_0.tar.bz2
URL: http://boost.org
Buildroot: /%{_tmppath}/%{name}-%{version}
BuildRequires: boost-jam >= 3.1
BuildArch: %{_target_cpu} noarch

%description
Boost is a collection of free peer-reviewed portable C++ source libraries. The
emphasis is on libraries which work well with the C++ Standard Library. This
package contains only the shared libraries needed for running programs using
Boost.

# Main package (contains *.so.[major]* only)
%package -n %{lib_name}
Summary:      The shared libraries needed for running programs using Boost
Group:        Development/C++
Provides:     %{lib_name_orig} = %{version}-%{release}
Provides:     %{name} = %{version}-%{release}
Obsoletes:    %{name} < 1.29.0-1payn

%description -n %{lib_name}
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains only the shared libraries
needed for running programs dynamically linked with Boost. Note that
many uses of Boost need only the headers, and will not require these
libraries.

# Debug package (contains *.so.[major]* only)
%package -n %{lib_name}-debug
Summary:      The shared libraries needed for running programs using Boost in debug mode
Group:        Development/C++
Provides:     %{lib_name_orig}-debug = %{version}-%{release}
Provides:     %{name}-debug = %{version}-%{release}
Conflicts:    %{name} < 1.29.0-2payn

%description -n %{lib_name}-debug
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains only the shared libraries
needed for running programs dynamically linked with the debug version
of Boost. Note that many uses of Boost need only the headers, and will
not require these libraries.

# -headers package (/usr/include/boost/* only)
%package -n %{lib_name}-headers
Summary:      The header files needed for Boost development
Group:        Development/C++
Provides:     %{lib_name_orig}-headers = %{version}-%{release}
Provides:     %{name}-headers = %{version}-%{release}
Obsoletes:    %{name}-devel < 1.29.0-1payn
# Does not require libboost1.29.0!

%description -n %{lib_name}-headers
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains only the include files. Note
that many uses of Boost need only these headers.

# Devel package (contains *.a, *.so, *.so.1, but not *.so.[major]*)
%package -n %{lib_name}-devel
Summary:      The libraries needed for Boost development
Group:        Development/C++
Provides:     %{lib_name_orig}-devel = %{version}-%{release}
Provides:     %{name}-devel = %{version}-%{release}
Requires:     %{name} = %{version}-%{release}
Requires:     %{name}-headers = %{version}-%{release}
Obsoletes:    %{name}-devel < 1.29.0-1payn
Requires:	%{lib_name} = %version-%name

%description -n %{lib_name}-devel
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains only the static libraries and
shared library symlinks needed for developing with Boost. Note that
many uses of Boost need only the headers, and will not require these
libraries.

# Debug-devel package (contains *.a, *.so, *.so.1, but not *.so.[major]*)
%package -n %{lib_name}-debug-devel
Summary:      The libraries needed for Boost debugging
Group:        Development/C++
Provides:     %{lib_name_orig}-debug-devel = %{version}-%{release}
Provides:     %{name}-debug-devel = %{version}-%{release}
Requires:     %{name} = %{version}-%{release}
Requires:     %{name}-headers = %{version}-%{release}
Requires:     %{name}-devel = %{version}-%{release}
Requires:     %{name}-debug = %{version}-%{release}
Conflicts:    %{name}-devel < 1.29.0-2payn
Requires:	%{lib_name}-debug = %{version}-%{release}

%description -n %{lib_name}-debug-devel
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains only the static libraries and
shared library symlinks needed for debugging programs developed with
Boost. Note that many uses of Boost need only the headers, and will
not require these libraries.

# Doc package
%package -n %{lib_name}-doc
Summary:      The documentation for the Boost libraries
Group:        Development/C++
Provides:     %{lib_name_orig}-doc = %{version}-%{release}
Provides:     %{name}-doc = %{version}-%{release}
Obsoletes:    %{name}-doc < 1.29.0-1payn

%description -n %{lib_name}-doc
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains the documentation.

# Examples package
%package -n %{lib_name}-examples
Summary:      The examples for the Boost libraries
Group:        Development/C++
Provides:     %{lib_name_orig}-examples = %{version}-%{release}
Provides:     %{name}-examples = %{version}-%{release}
Obsoletes:    %{name}-examples < 1.29.0-1payn

%description -n %{lib_name}-examples
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains examples, installed in the
same place as the documentation.

%prep
%setup -n boost_1_29_0

%build
# Preparing the docs
mkdir doc
cp --parents `find -name "*.html"` doc
cp --parents `find -name "*.htm"` doc
cp --parents `find -name "*.css"` doc
cp --parents `find -name "*.gif"` doc
cp --parents `find -name "*.jpg"` doc
cp --parents `find -name "*.png"` doc
cp --parents `find -name "*README*"` doc

# Preparing the examples: All .hpp or .cpp files that are not in
# directories called test, src, or tools, as well as all files of any
# type in directories called example or examples.
mkdir examples
cp --parents `find libs -name "*.?pp" ! -path "*test*" ! -path "*src*" ! -path "*tools*" -o -path "*example*" -type f` examples

RPM_BUILD_ROOT=`pwd`
BOOST_VERSION=%{version}
BOOST_MAJOR_VERSION=%{lib_major}
export RPM_BUILD_ROOT
export BOOST_VERSION

# TODO: Is there a better way to locate the python root?
PYTHON_BINARY=`which python`
PYTHON_ROOT=`dirname $PYTHON_BINARY`
PYTHON_ROOT=`dirname $PYTHON_ROOT`
export PYTHON_ROOT

# Building all of the libraries.
# This builds python, thread, signals, regex, and test. We ignore test.
# It does not build graph, because that seems to not work at present.
bjam -sTOOLS=gcc

%install
BOOST_VERSION=%{version}
BOOST_MAJOR_VERSION=%{lib_major}
export RPM_BUILD_ROOT
export BOOST_VERSION

%ifnarch noarch
mkdir -p $RPM_BUILD_ROOT/usr/lib

# TODO: Is this the best way to get all of the appropriate libraries?
cp libs/python/build/bin-stage/libboost_python.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib
ln -s libboost_python.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_python.so.$BOOST_MAJOR_VERSION
ln -s libboost_python.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_python.so.1
ln -s libboost_python.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_python.so
cp libs/python/build/bin-stage/libboost_python_debug.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib
ln -s libboost_python_debug.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_python_debug.so.$BOOST_MAJOR_VERSION
ln -s libboost_python_debug.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_python_debug.so.1
ln -s libboost_python_debug.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_python_debug.so

cp libs/regex/build/bin-stage/libboost_regex.a $RPM_BUILD_ROOT/usr/lib
cp libs/regex/build/bin-stage/libboost_regex_debug.a $RPM_BUILD_ROOT/usr/lib
cp libs/regex/build/bin-stage/libboost_regex.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib
ln -s libboost_regex.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_regex.so.$BOOST_MAJOR_VERSION
ln -s libboost_regex.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_regex.so.1
ln -s libboost_regex.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_regex.so
cp libs/regex/build/bin-stage/libboost_regex_debug.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib
ln -s libboost_regex_debug.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_regex_debug.so.$BOOST_MAJOR_VERSION
ln -s libboost_regex_debug.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_regex_debug.so.1
ln -s libboost_regex_debug.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_regex_debug.so

cp libs/signals/build/bin/libboost_signals.a/gcc/release/runtime-link-dynamic/libboost_signals.a $RPM_BUILD_ROOT/usr/lib
cp libs/signals/build/bin/libboost_signals.a/gcc/debug/runtime-link-dynamic/libboost_signals.a $RPM_BUILD_ROOT/usr/lib/libboost_signals_debug.a
cp libs/signals/build/bin/libboost_signals.so/gcc/release/runtime-link-dynamic/shared-linkable-true/libboost_signals.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib
ln -s libboost_signals.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_signals.so.$BOOST_MAJOR_VERSION
ln -s libboost_signals.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_signals.so.1
ln -s libboost_signals.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_signals.so
cp libs/signals/build/bin/libboost_signals.so/gcc/debug/runtime-link-dynamic/shared-linkable-true/libboost_signals.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_signals_debug.so.$BOOST_VERSION
ln -s libboost_signals_debug.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_signals_debug.so.$BOOST_MAJOR_VERSION
ln -s libboost_signals_debug.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_signals_debug.so.1
ln -s libboost_signals_debug.so.$BOOST_VERSION $RPM_BUILD_ROOT/usr/lib/libboost_signals_debug.so

cp libs/thread/build/bin/libboost_thread.a/gcc/release/runtime-link-dynamic/threading-multi/libboost_thread.a $RPM_BUILD_ROOT/usr/lib
cp libs/thread/build/bin/libboost_thread.a/gcc/release/runtime-link-static/threading-multi/libboost_thread.a $RPM_BUILD_ROOT/usr/lib/libboost_thread_static.a
cp libs/thread/build/bin/libboost_thread.a/gcc/debug/runtime-link-dynamic/threading-multi/libboost_thread.a $RPM_BUILD_ROOT/usr/lib/libboost_thread_debug.a
cp libs/thread/build/bin/libboost_thread.a/gcc/debug/runtime-link-static/threading-multi/libboost_thread.a $RPM_BUILD_ROOT/usr/lib/libboost_thread_static_debug.a
%endif

%ifarch noarch
mkdir -p $RPM_BUILD_ROOT/usr/include
cp -r boost $RPM_BUILD_ROOT/usr/include
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post -n %{lib_name} -p /sbin/ldconfig
%postun -n %{lib_name} -p /sbin/ldconfig

%post -n %{lib_name}-debug -p /sbin/ldconfig
%postun -n %{lib_name}-debug -p /sbin/ldconfig

%ifnarch noarch
%files -n %{lib_name}
%defattr(-,root,root)
/usr/lib/libboost_python.so.%{lib_major}*
/usr/lib/libboost_regex.so.%{lib_major}*
/usr/lib/libboost_signals.so.%{lib_major}*
%endif

%ifnarch noarch
%files -n %{lib_name}-debug
%defattr(-,root,root)
/usr/lib/libboost_python_debug.so.%{lib_major}*
/usr/lib/libboost_regex_debug.so.%{lib_major}*
/usr/lib/libboost_signals_debug.so.%{lib_major}*
%endif

%ifarch noarch
%files -n %{lib_name}-headers
%defattr(-,root,root)
/usr/include/boost
%endif

%ifnarch noarch
%files -n %{lib_name}-devel
%defattr(-,root,root)
/usr/lib/libboost_python.so
/usr/lib/libboost_python.so.1
/usr/lib/libboost_regex.a
/usr/lib/libboost_regex.so
/usr/lib/libboost_regex.so.1
/usr/lib/libboost_signals.a
/usr/lib/libboost_signals.so
/usr/lib/libboost_signals.so.1
/usr/lib/libboost_thread.a
/usr/lib/libboost_thread_static.a
%endif

%ifnarch noarch
%files -n %{lib_name}-debug-devel
%defattr(-,root,root)
/usr/lib/libboost_python_debug.so
/usr/lib/libboost_python_debug.so.1
/usr/lib/libboost_regex_debug.a
/usr/lib/libboost_regex_debug.so
/usr/lib/libboost_regex_debug.so.1
/usr/lib/libboost_signals_debug.a
/usr/lib/libboost_signals_debug.so
/usr/lib/libboost_signals_debug.so.1
/usr/lib/libboost_thread_debug.a
/usr/lib/libboost_thread_static_debug.a
%endif

%ifarch noarch
%files -n %{lib_name}-doc
%defattr(-,root,root)
%doc doc/*
%endif

%ifarch noarch
%files -n %{lib_name}-examples
%defattr(-,root,root)
%doc examples/*
%endif

%changelog
* Tue Mar 18 2003 Lenny Cartier <lenny@mandrakesoft.com> 1.29.0-4mdk
- from andi payn <payn@myrealbox.com> :
	- complete the Mandrakization process

* Fri Jan 11 2003 - andi payn <payn@myrealbox.com> 1.29.0-3payn
- add examples

* Fri Jan 11 2003 - andi payn <payn@myrealbox.com> 1.29.0-2payn
- make headers and doc packages noarch
- move debug libraries into -debug and -debug-devel

* Fri Jan 11 2003 - andi payn <payn@myrealbox.com> 1.29.0-1payn
- reorganize packaging to use Mandrake library RPM policy
- move from Development/Language/C++ to Development/C++
- add *.so.1.29 and *.so.1
- add ldconfig post/postun script 

* Fri Jan 10 2003 - payn@myrealbox.com
- update to Boost 1.29.0
- use boost-jam to build libraries

* Fri Jul 20 2001 - gerhard@bigfoot.de
- build Boost.Python as shared library

* Sat Jul 07 2001 - gerhard@bigfoot.de
- update to Boost 1.23.0

* Sun Apr 29 2001 - gerhard@bigfoot.de
- created RPM
